@@ -8,10 +8,9 @@ check_eng_args <- function(args, obj, core_args) {
   if (length(common_args) > 0) {
     args <- args[!(names(args) %in% common_args)]
     common_args <- paste0(common_args, collapse = ", ")
-    rlang::warn(glue::glue(
-      "The following arguments cannot be manually modified ",
-      "and were removed: {common_args}."
-    ))
+    cli::cli_warn(
+      "The arguments {common_args} cannot be manually modified and were removed."
+    )
   }
   args
 }
@@ -25,11 +24,12 @@ make_x_call <- function(object, target) {
   }
 
   object$method$fit$args[[unname(data_args["x"])]] <-
-    switch(target,
+    switch(
+      target,
       none = rlang::expr(x),
       data.frame = rlang::expr(maybe_data_frame(x)),
       matrix = rlang::expr(maybe_matrix(x)),
-      rlang::abort(glue::glue("Invalid data type target: {target}."))
+      cli::cli_abort("Invalid data type target: {target}.")
     )
 
   fit_call <- make_call(
@@ -75,7 +75,7 @@ make_form_call <- function(object, env = NULL) {
 set_args.cluster_spec <- function(object, ...) {
   the_dots <- enquos(...)
   if (length(the_dots) == 0) {
-    rlang::abort("Please pass at least one named argument.")
+    cli::cli_abort("Please pass at least one named argument.")
   }
   main_args <- names(object$args)
   new_args <- names(the_dots)
@@ -101,7 +101,7 @@ set_args.cluster_spec <- function(object, ...) {
 #' @inheritParams parsnip::set_mode
 #' @return An updated [`cluster_spec`] object.
 #' @export
-set_mode.cluster_spec <- function(object, mode) {
+set_mode.cluster_spec <- function(object, mode, ...) {
   cls <- class(object)[1]
   if (rlang::is_missing(mode)) {
     spec_modes <- rlang::env_get(
