@@ -10,7 +10,7 @@ extract_parameter_set_dials.cluster_spec <- function(x, ...) {
       all_args,
       by = c("name", "source", "component")
     ) %>%
-    dplyr::mutate(object = map(call_info, eval_call_info))
+      dplyr::mutate(object = map(call_info, eval_call_info))
 
   dials::parameters_constr(
     res$name,
@@ -36,11 +36,7 @@ eval_call_info <- function(x) {
       silent = TRUE
     )
     if (inherits(res, "try-error")) {
-      rlang::abort(
-        glue::glue(
-          "Error when calling {x$fun}(): {as.character(res)}"
-        )
-      )
+      cli::cli_abort("Error when calling {.fn {x$fun}}: {as.character(res)}")
     }
   } else {
     res <- NA
