@@ -85,13 +85,15 @@
 #' @return A fitted [`cluster_fit`] object.
 #' @export
 #' @export fit.cluster_spec
-fit.cluster_spec <- function(object,
-                             formula,
-                             data,
-                             control = control_cluster(),
-                             ...) {
+fit.cluster_spec <- function(
+  object,
+  formula,
+  data,
+  control = control_cluster(),
+  ...
+) {
   if (object$mode == "unknown") {
-    rlang::abort("Please set the mode in the model specification.")
+    cli::cli_abort("Please set the mode in the model specification.")
   }
 
   control <- parsnip::condense_control(control, control_cluster())
@@ -101,13 +103,14 @@ fit.cluster_spec <- function(object,
     eng_vals <- possible_engines(object)
     object$engine <- eng_vals[1]
     if (control$verbosity > 0) {
-      rlang::warn(glue::glue("Engine set to `{object$engine}`."))
+      cli::cli_warn("Engine set to {.code {object$engine}}.")
     }
   }
 
   if (all(c("x", "y") %in% names(dots))) {
-    rlang::abort(
-      "`fit.cluster_spec()` is for the formula methods. Use `fit_xy()` instead."
+    cli::cli_abort(
+      "The {.fn fit.cluster_spec} function is for the formula methods. 
+      Use {.fn fit_xy} instead."
     )
   }
   cl <- match.call(expand.dots = TRUE)
@@ -133,33 +136,31 @@ fit.cluster_spec <- function(object,
   # used here, `fit_interface_formula` will determine if a
   # translation has to be made if the model interface is x/y/
   res <-
-    switch(interfaces,
+    switch(
+      interfaces,
       # homogeneous combinations:
-      formula_formula =
-        form_form(
-          object = object,
-          control = control,
-          env = eval_env
-        ),
+      formula_formula = form_form(
+        object = object,
+        control = control,
+        env = eval_env
+      ),
 
       # heterogenous combinations
-      formula_matrix =
-        form_x(
-          object = object,
-          control = control,
-          env = eval_env,
-          target = object$method$fit$interface,
-          ...
-        ),
-      formula_data.frame =
-        form_x(
-          object = object,
-          control = control,
-          env = eval_env,
-          target = object$method$fit$interface,
-          ...
-        ),
-      rlang::abort(glue::glue("{interfaces} is unknown."))
+      formula_matrix = form_x(
+        object = object,
+        control = control,
+        env = eval_env,
+        target = object$method$fit$interface,
+        ...
+      ),
+      formula_data.frame = form_x(
+        object = object,
+        control = control,
+        env = eval_env,
+        target = object$method$fit$interface,
+        ...
+      ),
+      cli::cli_abort("{interfaces} is unknown.")
     )
   model_classes <- class(res$fit)
   class(res) <- c(paste0("_", model_classes[1]), "cluster_fit")
@@ -176,7 +177,7 @@ check_interface <- function(formula, data, cl, model) {
   if (form_interface) {
     return("formula")
   }
-  rlang::abort("Error when checking the interface.")
+  cli::cli_abort("Error when checking the interface.")
 }
 
 inher <- function(x, cls, cl) {
@@ -184,16 +185,9 @@ inher <- function(x, cls, cl) {
     call <- match.call()
     obj <- deparse(call[["x"]])
     if (length(cls) > 1) {
-      rlang::abort(
-        glue::glue(
-          "`{obj}` should be one of the following classes: ",
-          glue::glue_collapse(glue::glue("'{cls}'"), sep = ", ")
-        )
-      )
+      cli::cli_abort("{.code {obj}} should be {.cls {cls}}.")
     } else {
-      rlang::abort(
-        glue::glue("`{obj}` should be a {cls} object")
-      )
+      cli::cli_abort("{.code {obj}} should be {.obj_type_friendly {cls}}.")
     }
   }
   invisible(x)
@@ -241,14 +235,14 @@ fit_xy.cluster_spec <-
     control <- parsnip::condense_control(control, control_cluster())
 
     if (is.null(colnames(x))) {
-      rlang::abort("'x' should have column names.")
+      cli::cli_abort("{.arg x} should have column names.")
     }
 
     if (is.null(object$engine)) {
       eng_vals <- possible_engines(object)
       object$engine <- eng_vals[1]
       if (control$verbosity > 0) {
-        rlang::warn(glue::glue("Engine set to `{object$engine}`."))
+        cli::cli_warn("Engine set to {.code {object$engine}}.")
       }
     }
 
@@ -270,37 +264,35 @@ fit_xy.cluster_spec <-
     # used here, `fit_interface_formula` will determine if a
     # translation has to be made if the model interface is x/y/
     res <-
-      switch(interfaces,
+      switch(
+        interfaces,
         # homogeneous combinations:
         matrix_matrix = ,
-        data.frame_matrix =
-          x_x(
-            object = object,
-            env = eval_env,
-            control = control,
-            target = "matrix",
-            ...
-          ),
+        data.frame_matrix = x_x(
+          object = object,
+          env = eval_env,
+          control = control,
+          target = "matrix",
+          ...
+        ),
         data.frame_data.frame = ,
-        matrix_data.frame =
-          x_x(
-            object = object,
-            env = eval_env,
-            control = control,
-            target = "data.frame",
-            ...
-          ),
+        matrix_data.frame = x_x(
+          object = object,
+          env = eval_env,
+          control = control,
+          target = "data.frame",
+          ...
+        ),
 
         # heterogenous combinations
         matrix_formula = ,
-        data.frame_formula =
-          x_form(
-            object = object,
-            env = eval_env,
-            control = control,
-            ...
-          ),
-        rlang::abort(glue::glue("{interfaces} is unknown."))
+        data.frame_formula = x_form(
+          object = object,
+          env = eval_env,
+          control = control,
+          ...
+        ),
+        cli::cli_abort("{interfaces} is unknown.")
       )
     model_classes <- class(res$fit)
     class(res) <- c(paste0("_", model_classes[1]), "cluster_fit")
@@ -311,7 +303,7 @@ check_x_interface <- function(x, cl, model) {
   sparse_ok <- allow_sparse(model)
   sparse_x <- inherits(x, "dgCMatrix")
   if (!sparse_ok && sparse_x) {
-    rlang::abort(
+    cli::cli_abort(
       "Sparse matrices not supported by this model/engine combination."
     )
   }
@@ -336,7 +328,7 @@ check_x_interface <- function(x, cl, model) {
   if (df_interface) {
     return("data.frame")
   }
-  rlang::abort("Error when checking the interface")
+  cli::cli_abort("Error when checking the interface")
 }
 
 allow_sparse <- function(x) {
