@@ -19,12 +19,18 @@
 #'
 #' sse_within(kmeans_fit)
 #' @export
-sse_within <- function(object, new_data = NULL, dist_fun = Rfast::dista) {
+sse_within <- function(
+  object,
+  new_data = NULL,
+  dist_fun = function(x, y) {
+    philentropy::dist_many_many(x, y, method = "euclidean")
+  }
+) {
   if (inherits(object, "cluster_spec")) {
-    rlang::abort(
-      paste(
+    cli::cli_abort(
+      c(
         "This function requires a fitted model.",
-        "Please use `fit()` on your cluster specification."
+        "i" = "Please use {.fn fit} on your cluster specification."
       )
     )
   }
@@ -43,14 +49,21 @@ sse_within <- function(object, new_data = NULL, dist_fun = Rfast::dista) {
       n_members = summ$n_members
     )
   } else {
-    dist_to_centroids <- dist_fun(summ$centroids, new_data)
+    suppressMessages(
+      dist_to_centroids <- dist_fun(
+        as.matrix(summ$centroids),
+        as.matrix(new_data)
+      )
+    )
 
     res <- dist_to_centroids %>%
       tibble::as_tibble(.name_repair = "minimal") %>%
-      map(~ c(
-        .cluster = which.min(.x),
-        dist = min(.x)^2
-      )) %>%
+      map(
+        ~c(
+          .cluster = which.min(.x),
+          dist = min(.x)^2
+        )
+      ) %>%
       dplyr::bind_rows() %>%
       dplyr::mutate(
         .cluster = factor(paste0("Cluster_", .cluster))
@@ -102,20 +115,26 @@ sse_within_total <- new_cluster_metric(
 #' @export
 #' @rdname sse_within_total
 sse_within_total.cluster_spec <- function(object, ...) {
-  rlang::abort(
-    paste(
+  cli::cli_abort(
+    c(
       "This function requires a fitted model.",
-      "Please use `fit()` on your cluster specification."
+      "i" = "Please use {.fn fit} on your cluster specification."
     )
   )
 }
 
 #' @export
 #' @rdname sse_within_total
-sse_within_total.cluster_fit <- function(object, new_data = NULL,
-                                         dist_fun = NULL, ...) {
+sse_within_total.cluster_fit <- function(
+  object,
+  new_data = NULL,
+  dist_fun = NULL,
+  ...
+) {
   if (is.null(dist_fun)) {
-    dist_fun <- Rfast::dista
+    dist_fun <- function(x, y) {
+      philentropy::dist_many_many(x, y, method = "euclidean")
+    }
   }
 
   res <- sse_within_total_impl(object, new_data, dist_fun, ...)
@@ -133,13 +152,25 @@ sse_within_total.workflow <- sse_within_total.cluster_fit
 
 #' @export
 #' @rdname sse_within_total
-sse_within_total_vec <- function(object, new_data = NULL,
-                                 dist_fun = Rfast::dista, ...) {
+sse_within_total_vec <- function(
+  object,
+  new_data = NULL,
+  dist_fun = function(x, y) {
+    philentropy::dist_many_many(x, y, method = "euclidean")
+  },
+  ...
+) {
   sse_within_total_impl(object, new_data, dist_fun, ...)
 }
 
-sse_within_total_impl <- function(object, new_data = NULL,
-                                  dist_fun = Rfast::dista, ...) {
+sse_within_total_impl <- function(
+  object,
+  new_data = NULL,
+  dist_fun = function(x, y) {
+    philentropy::dist_many_many(x, y, method = "euclidean")
+  },
+  ...
+) {
   sum(sse_within(object, new_data, dist_fun, ...)$wss, na.rm = TRUE)
 }
 
@@ -177,20 +208,26 @@ sse_total <- new_cluster_metric(
 #' @export
 #' @rdname sse_total
 sse_total.cluster_spec <- function(object, ...) {
-  rlang::abort(
-    paste(
+  cli::cli_abort(
+    c(
       "This function requires a fitted model.",
-      "Please use `fit()` on your cluster specification."
+      "i" = "Please use {.fn fit} on your cluster specification."
     )
   )
 }
 
 #' @export
 #' @rdname sse_total
-sse_total.cluster_fit <- function(object, new_data = NULL, dist_fun = NULL,
-                                  ...) {
+sse_total.cluster_fit <- function(
+  object,
+  new_data = NULL,
+  dist_fun = NULL,
+  ...
+) {
   if (is.null(dist_fun)) {
-    dist_fun <- Rfast::dista
+    dist_fun <- function(x, y) {
+      philentropy::dist_many_many(x, y, method = "euclidean")
+    }
   }
 
   res <- sse_total_impl(object, new_data, dist_fun, ...)
@@ -208,12 +245,25 @@ sse_total.workflow <- sse_total.cluster_fit
 
 #' @export
 #' @rdname sse_total
-sse_total_vec <- function(object, new_data = NULL, dist_fun = Rfast::dista, ...) {
+sse_total_vec <- function(
+  object,
+  new_data = NULL,
+  dist_fun = function(x, y) {
+    philentropy::dist_many_many(x, y, method = "euclidean")
+  },
+  ...
+) {
   sse_total_impl(object, new_data, dist_fun, ...)
 }
 
-sse_total_impl <- function(object, new_data = NULL, dist_fun = Rfast::dista,
-                           ...) {
+sse_total_impl <- function(
+  object,
+  new_data = NULL,
+  dist_fun = function(x, y) {
+    philentropy::dist_many_many(x, y, method = "euclidean")
+  },
+  ...
+) {
   # Preprocess data before computing distances if appropriate
   if (inherits(object, "workflow") && !is.null(new_data)) {
     new_data <- extract_post_preprocessor(object, new_data)
@@ -226,7 +276,10 @@ sse_total_impl <- function(object, new_data = NULL, dist_fun = Rfast::dista,
   } else {
     overall_mean <- colSums(summ$centroids * summ$n_members) /
       sum(summ$n_members)
-    tot <- dist_fun(t(as.matrix(overall_mean)), new_data)^2 %>% sum()
+    suppressMessages(
+      tot <- dist_fun(t(as.matrix(overall_mean)), as.matrix(new_data))^2 %>%
+        sum()
+    )
   }
 
   return(tot)
@@ -266,20 +319,26 @@ sse_ratio <- new_cluster_metric(
 #' @export
 #' @rdname sse_ratio
 sse_ratio.cluster_spec <- function(object, ...) {
-  rlang::abort(
-    paste(
+  cli::cli_abort(
+    c(
       "This function requires a fitted model.",
-      "Please use `fit()` on your cluster specification."
+      "i" = "Please use {.fn fit} on your cluster specification."
     )
   )
 }
 
 #' @export
 #' @rdname sse_ratio
-sse_ratio.cluster_fit <- function(object, new_data = NULL,
-                                  dist_fun = NULL, ...) {
+sse_ratio.cluster_fit <- function(
+  object,
+  new_data = NULL,
+  dist_fun = NULL,
+  ...
+) {
   if (is.null(dist_fun)) {
-    dist_fun <- Rfast::dista
+    dist_fun <- function(x, y) {
+      philentropy::dist_many_many(x, y, method = "euclidean")
+    }
   }
   res <- sse_ratio_impl(object, new_data, dist_fun, ...)
 
@@ -296,17 +355,25 @@ sse_ratio.workflow <- sse_ratio.cluster_fit
 
 #' @export
 #' @rdname sse_ratio
-sse_ratio_vec <- function(object,
-                          new_data = NULL,
-                          dist_fun = Rfast::dista,
-                          ...) {
+sse_ratio_vec <- function(
+  object,
+  new_data = NULL,
+  dist_fun = function(x, y) {
+    philentropy::dist_many_many(x, y, method = "euclidean")
+  },
+  ...
+) {
   sse_ratio_impl(object, new_data, dist_fun, ...)
 }
 
-sse_ratio_impl <- function(object,
-                           new_data = NULL,
-                           dist_fun = Rfast::dista,
-                           ...) {
+sse_ratio_impl <- function(
+  object,
+  new_data = NULL,
+  dist_fun = function(x, y) {
+    philentropy::dist_many_many(x, y, method = "euclidean")
+  },
+  ...
+) {
   sse_within_total_vec(object, new_data, dist_fun) /
     sse_total_vec(object, new_data, dist_fun)
 }
