@@ -2,7 +2,7 @@
 #' @export
 required_pkgs.cluster_spec <- function(x, infra = TRUE, ...) {
   if (is.null(x$engine)) {
-    rlang::abort("Please set an engine.")
+    cli::cli_abort("Please set an engine.")
   }
   get_pkgs(x, infra)
 }
@@ -16,7 +16,7 @@ get_pkgs <- function(x, infra) {
   cls <- class(x)[1]
   pkgs <-
     modelenv::get_from_env(paste0(cls, "_pkgs")) %>%
-    dplyr::filter(engine == x$engine)
+      dplyr::filter(engine == x$engine)
   res <- pkgs$pkg[[1]]
   if (length(res) == 0) {
     res <- character(0)
