@@ -1,14 +1,18 @@
-new_rng_snapshots <- utils::compareVersion("3.6.0", as.character(getRversion())) > 0
+new_rng_snapshots <- utils::compareVersion(
+  "3.6.0",
+  as.character(getRversion())
+) >
+  0
 
 helper_objects_tidyclust <- function() {
   rec_tune_1 <-
     recipes::recipe(~., data = mtcars) %>%
-    recipes::step_normalize(recipes::all_predictors()) %>%
-    recipes::step_pca(recipes::all_predictors(), num_comp = tune())
+      recipes::step_normalize(recipes::all_predictors()) %>%
+      recipes::step_pca(recipes::all_predictors(), num_comp = tune())
 
   rec_no_tune_1 <-
     recipes::recipe(~., data = mtcars) %>%
-    recipes::step_normalize(recipes::all_predictors())
+      recipes::step_normalize(recipes::all_predictors())
 
   kmeans_mod_no_tune <- k_means(num_clusters = 2)
 
