@@ -1,7 +1,6 @@
 test_that("fit and fit_xy errors if outcome is provided", {
-  expect_error(
-    k_means(num_clusters = 5) %>% fit_xy(mtcars),
-    regexp = NA
+  expect_no_error(
+    k_means(num_clusters = 5) %>% fit_xy(mtcars)
   )
 
   expect_snapshot(
@@ -12,9 +11,8 @@ test_that("fit and fit_xy errors if outcome is provided", {
 
   km <- k_means(num_clusters = 5)
 
-  expect_error(
-    workflows::workflow(~., km) %>% fit(mtcars),
-    regexp = NA
+  expect_no_error(
+    workflows::workflow(~., km) %>% fit(mtcars)
   )
   expect_snapshot(
     error = TRUE,
